==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sk-SK/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategórie majetku',
    'category_name'  					=> 'Názov kategórie',
    'checkin_email'                     => 'Poslať email používateľovi pri prijatí / odovzdaní.',
    'checkin_email_notification'        => 'Používateľovi bude odoslaný mail pri prijatí / odovzdaní.',
    'clone'                             => 'Duplikovať kategóriu',
    'create'  							=> 'Vytvoriť kategóriu',
    'edit'                              => 'Upraviť kategóriu',
    'email_will_be_sent_due_to_global_eula' => 'Používateľovi bude zaslaný mail pretože sa používa globálna EULA.',
    'email_will_be_sent_due_to_category_eula' => 'Používateľovi bude zaslaný mail pretože je pre zvolenú kategóriu nastavená EULA.',
    'eula_text'							=> 'Kategória EULA',
    'eula_text_help'					=> 'Toto políčko umožňuje prispôsobiť dokument EULA špecifikcému typu majetku. Ak máte iba jeden dokument EULA pre všetky typy majetku, môžete oznaciť možnosť nižšie, aby sa použil predvolený dokument.',
    'name'                              => 'Názov kategórie',
    'require_acceptance'				=> 'Vyžadovač od používatľov aby potvrdili prijatie majetku v tejto kategórii.',
    'required_acceptance'				=> 'Tomuto používateľovi bude zaslaný mailom odkaz na potvrdenie prijatia tejto položky.',
    'required_eula'						=> 'Tomuto používateľovi bude zaslaná kópia dokumentu EULA',
    'no_default_eula'					=> 'Žiaden predvolený EULA dokument nebol nájdený. Pridajte nový v Nastaveniach.',
    'update'  							=> 'Upraviť kategóriu',
    'use_default_eula'					=> 'Použiť <a href="#" data-toggle="modal" data-target="#eulaModal">predvolený dokument EULA</a> namiesto toho.',
    'use_default_eula_disabled'			=> '<del>Použiť namiesto toho predvolený dokument EULA.</del> Predvolený dokument EULA nie je nastavený. Prosím vyberte predvolený dokument v Nastaveniach.',
    'use_default_eula_column'			=> 'Použiť predvolenú EULA',

);

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sk-SK/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategórie majetku',
    'category_name'  					=> 'Názov kategórie',
    'checkin_email'                     => 'Poslať email používateľovi pri prevzatí / odovzdaní.',
    'checkin_email_notification'        => 'Používateľovi bude odoslaný mail pri prevzatí / odovzdaní.',
    'clone'                             => 'Duplikovať kategóriu',
    'create'  							=> 'Vytvoriť kategóriu',
    'edit'                              => 'Upraviť kategóriu',
    'email_will_be_sent_due_to_global_eula' => 'Používateľovi bude zaslaný mail pretože sa používa globálna EULA.',
    'email_will_be_sent_due_to_category_eula' => 'Používateľovi bude zaslaný mail pretože je pre zvolenú kategóriu nastavená EULA.',
    'eula_text'							=> 'Kategória EULA',
    'eula_text_help'					=> 'Toto políčko umožňuje prispôsobiť EULA špecifickému typu majetku. Ak máte iba jednu EULA pre všetky typy majetku, môžete označiť možnosť nižšie, aby sa použila predvolená.',
    'name'                              => 'Názov kategórie',
    'require_acceptance'				=> 'Vyžadovať od používateľov aby potvrdili prijatie majetku v tejto kategórii.',
    'required_acceptance'				=> 'Tomuto používateľovi bude zaslaný mailom odkaz na potvrdenie prijatia tejto položky.',
    'required_eula'						=> 'Tomuto používateľovi bude zaslaná kópia dokumentu EULA',
    'no_default_eula'					=> 'Žiaden predvolený EULA dokument nebol nájdený. Pridajte nový v Nastaveniach.',
    'update'  							=> 'Upraviť kategóriu',
    'use_default_eula'					=> 'Použiť <a href="#" data-toggle="modal" data-target="#eulaModal">predvolený dokument EULA</a> namiesto toho.',
    'use_default_eula_disabled'			=> '<del>Použiť namiesto toho predvolený dokument EULA.</del> Predvolený dokument EULA nie je nastavený. Prosím vyberte predvolený dokument v Nastaveniach.',
    'use_default_eula_column'			=> 'Použiť predvolenú EULA',

);
